@@ -22,13 +22,13 @@
 
 get_intvl_limit <- function(x_new, model, alpha = 0.05, ivl = "confidence",
                          ivl_type = "one.sided", ivl_side = "lower") {
-  if (!is.numeric(x_new) & !is.na(x_new)) {
+  if (!is.numeric(x_new) && !is.na(x_new)) {
     stop("x_new must be a numeric value.")
   }
   if (!inherits(model, "lm")) {
     stop("Please provide a model of type \"lm\".")
   }
-  if (alpha <= 0 | alpha > 1) {
+  if (alpha <= 0 || alpha > 1) {
     stop("Please specify alpha as (0, 1].")
   }
   if (!(ivl %in% c("confidence", "prediction", "fitted.line"))) {
@@ -60,7 +60,7 @@ get_intvl_limit <- function(x_new, model, alpha = 0.05, ivl = "confidence",
   variable_names <- names(attr(model$terms, which = "dataClasses"))
   is_factor <- sum(attr(model$terms, which = "dataClasses") %in% "factor")
 
-  if (is_factor == 0 & length(variable_names) == 2) {
+  if (is_factor == 0 && length(variable_names) == 2) {
     l_newdata <- list(x_new)
     names(l_newdata) <- variable_names[2]
 
@@ -88,18 +88,20 @@ get_intvl_limit <- function(x_new, model, alpha = 0.05, ivl = "confidence",
       variable_names[attr(model$terms, which = "dataClasses") %in% "factor"]
 
     x_length <- vapply(grouping_variables,
-                       function(x)
-                         nlevels(model$model[, grouping_variables]),
+                       function(x) {
+                         nlevels(model$model[, grouping_variables])
+                       },
                        numeric(1))
     x_length <- prod(x_length)
 
     l_newdata <-
       vapply(grouping_variables,
-             function(x)
+             function(x) {
                list(rep(levels(model$model[, grouping_variables]),
                         each = x_length /
                           nlevels(model$model[, grouping_variables]) *
-                          length(x_new))),
+                          length(x_new)))
+             },
              list(1))
     l_newdata[[length(l_newdata) + 1]] <- rep(x_new, x_length)
     names(l_newdata) <- c(grouping_variables,
@@ -194,10 +196,10 @@ get_distance <- function(x_new, model, sl, alpha = 0.05, ivl = "confidence",
   if (!inherits(model, "lm")) {
     stop("Please provide a model of type \"lm\".")
   }
-  if (!is.numeric(sl) | length(sl) > 1) {
+  if (!is.numeric(sl) || length(sl) > 1) {
     stop("sl must be a numeric value of length 1.")
   }
-  if (alpha <= 0 | alpha > 1) {
+  if (alpha <= 0 || alpha > 1) {
     stop("Please specify alpha as (0, 1].")
   }
   if (!(ivl %in% c("confidence", "prediction", "fitted.line"))) {
@@ -276,16 +278,16 @@ get_distance <- function(x_new, model, sl, alpha = 0.05, ivl = "confidence",
 
 find_poi <- function(srch_range, model, sl, alpha = 0.05, ivl = "confidence",
                      ivl_type = "one.sided", ivl_side = "lower", ...) {
-  if (!is.numeric(srch_range) | length(srch_range) != 2) {
+  if (!is.numeric(srch_range) || length(srch_range) != 2) {
     stop("The parameter srch_range must be a vector of length 2.")
   }
   if (!inherits(model, "lm")) {
     stop("Please provide a model of type \"lm\".")
   }
-  if (!is.numeric(sl) | length(sl) > 1) {
+  if (!is.numeric(sl) || length(sl) > 1) {
     stop("sl must be a numeric value of length 1.")
   }
-  if (alpha <= 0 | alpha > 1) {
+  if (alpha <= 0 || alpha > 1) {
     stop("Please specify alpha as (0, 1].")
   }
   if (!(ivl %in% c("confidence", "prediction", "fitted.line"))) {
@@ -352,11 +354,11 @@ get_xformed_variables <- function(data, response_vbl, time_vbl,
   if (length(xform) != 2) {
     stop("Please specify xform appropriately.")
   }
-  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) |
+  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) ||
       !(xform[2] %in% c("no", "log", "sqrt", "sq"))) {
     stop("Please specify xform appropriately.")
   }
-  if (!is.numeric(shift) | length(shift) != 2) {
+  if (!is.numeric(shift) || length(shift) != 2) {
     stop("The parameter shift must be a numeric vector of length 2.")
   }
 
@@ -445,7 +447,7 @@ get_variable_list <- function(response_vbl, time_vbl, batch_vbl,
   if (length(xform) != 2) {
     stop("Please specify xform appropriately.")
   }
-  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) |
+  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) ||
       !(xform[2] %in% c("no", "log", "sqrt", "sq"))) {
     stop("Please specify xform appropriately.")
   }
@@ -477,13 +479,13 @@ get_variable_list <- function(response_vbl, time_vbl, batch_vbl,
            })
   }
 
-  if (xform[1] == "no" & xform[2] == "no") {
+  if (xform[1] == "no" && xform[2] == "no") {
     l_variables <- list(batch = batch_vbl,
                         response = response_vbl,
                         time = time_vbl)
   }
 
-  if (xform[1] != "no" & xform[2] != "no") {
+  if (xform[1] != "no" && xform[2] != "no") {
     l_variables <- list(batch = batch_vbl,
                         response.orig = response_vbl,
                         response = new_response_vbl,
@@ -557,22 +559,22 @@ get_variable_list <- function(response_vbl, time_vbl, batch_vbl,
 set_limits <- function(rl, rl_sf, sl, sl_sf, sf_option = "loose",
                        xform = c("no", "no"), shift = c(0, 0),
                        ivl_side = "lower") {
-  if (!is.numeric(rl) & all(!is.na(rl))) {
+  if (!is.numeric(rl) && all(!is.na(rl))) {
     stop("The parameter rl must be a numeric value or NA.")
   }
-  if (!is.numeric(rl_sf) & all(!is.na(rl_sf))) {
+  if (!is.numeric(rl_sf) && all(!is.na(rl_sf))) {
     stop("The parameter rl_sf must be a positive integer of length rl, or NA.")
   }
-  if (sum(rl_sf < 0) > 0 & all(!is.na(rl_sf))) {
+  if (sum(rl_sf < 0) > 0 && all(!is.na(rl_sf))) {
     stop("The parameter rl_sf must be a positive integer of length rl, or NA.")
   }
   if (length(rl_sf) != length(rl)) {
     stop("The parameter rl_sf must be a positive integer of length rl, or NA.")
   }
-  if (!isTRUE(all.equal(rl_sf, as.integer(rl_sf))) & all(!is.na(rl_sf))) {
+  if (!isTRUE(all.equal(rl_sf, as.integer(rl_sf))) && all(!is.na(rl_sf))) {
     stop("The parameter rl_sf must be a positive integer of length rl, or NA.")
   }
-  if (!is.numeric(sl) | length(sl) > 2) {
+  if (!is.numeric(sl) || length(sl) > 2) {
     stop("The parameter sl must be a numeric value or vector of length 1 or 2.")
   }
   if (length(sl) == 2) {
@@ -580,7 +582,7 @@ set_limits <- function(rl, rl_sf, sl, sl_sf, sf_option = "loose",
       stop("The parameter sl must be of the form c(lower, upper).")
     }
   }
-  if (!is.numeric(sl_sf) & all(!is.na(sl_sf))) {
+  if (!is.numeric(sl_sf) && all(!is.na(sl_sf))) {
     stop("The parameter sl_sf must be a positive integer of length sl.")
   }
   if (sum(sl_sf < 0) > 0) {
@@ -598,11 +600,11 @@ set_limits <- function(rl, rl_sf, sl, sl_sf, sf_option = "loose",
   if (length(xform) != 2) {
     stop("Please specify xform appropriately.")
   }
-  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) |
+  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) ||
       !(xform[2] %in% c("no", "log", "sqrt", "sq"))) {
     stop("Please specify xform appropriately.")
   }
-  if (!is.numeric(shift) | length(shift) != 2) {
+  if (!is.numeric(shift) || length(shift) != 2) {
     stop("The parameter shift must be a numeric vector of length 2.")
   }
   if (!(ivl_side %in% c("lower", "upper"))) {
@@ -773,8 +775,7 @@ set_limits <- function(rl, rl_sf, sl, sl_sf, sf_option = "loose",
 #' Therapeutic Goods Administration (TGA) of the Department of Health of the
 #' Australian Government, Australian Regulatory Guidelines for Prescription
 #' Medicines (ARGPM), Stability testing for prescription medicines,
-#' Version 1.1, March 2017 \cr
-#' \url{https://www.tga.gov.au/stability-testing-prescription-medicines}
+#' Version 1.1, March 2017
 #'
 #' @seealso \code{\link{expirest_wisle}}, \code{\link[stats]{lm}}.
 #'
@@ -782,10 +783,10 @@ set_limits <- function(rl, rl_sf, sl, sl_sf, sf_option = "loose",
 
 get_wcs_limit <- function(rl, sl, intercept, xform = c("no", "no"),
                           shift = c(0, 0), ivl_side = "lower") {
-  if (!is.numeric(rl) | length(rl) > 1) {
+  if (!is.numeric(rl) || length(rl) > 1) {
     stop("The parameter rl must be a numeric value of length 1.")
   }
-  if (!is.numeric(sl) | length(sl) > 1) {
+  if (!is.numeric(sl) || length(sl) > 1) {
     stop("The parameter sl must be a numeric value of length 1.")
   }
   if (!is.numeric(intercept)) {
@@ -794,21 +795,21 @@ get_wcs_limit <- function(rl, sl, intercept, xform = c("no", "no"),
   if (length(xform) != 2) {
     stop("Please specify xform appropriately.")
   }
-  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) |
+  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) ||
       !(xform[2] %in% c("no", "log", "sqrt", "sq"))) {
     stop("Please specify xform appropriately.")
   }
-  if (!is.numeric(shift) | length(shift) != 2) {
+  if (!is.numeric(shift) || length(shift) != 2) {
     stop("The parameter shift must be a numeric vector of length 2.")
   }
   if (!(ivl_side %in% c("lower", "upper"))) {
     stop("Please specify ivl_side either as \"lower\" or \"upper\".")
   }
 
-  if (ivl_side == "lower" & rl < sl) {
+  if (ivl_side == "lower" && any(rl < sl)) {
     stop("If ivl_side is \"lower\" rl must be > sl.")
   }
-  if (ivl_side == "upper" & rl > sl) {
+  if (ivl_side == "upper" && any(rl > sl)) {
     stop("If ivl_side is \"upper\" rl must be < sl.")
   }
 
@@ -925,7 +926,7 @@ check_ancova <- function(data, response_vbl, time_vbl, batch_vbl,
   if (!is.factor(data[, batch_vbl])) {
     stop("The column in data specified by batch_vbl must be a factor.")
   }
-  if (alpha <= 0 | alpha > 1) {
+  if (alpha <= 0 || alpha > 1) {
     stop("Please specify alpha as (0, 1].")
   }
 
@@ -1014,11 +1015,11 @@ get_icpt <- function(model, response_vbl, time_vbl, batch_vbl,
   if (length(xform) != 2) {
     stop("Please specify xform appropriately.")
   }
-  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) |
+  if (!(xform[1] %in% c("no", "log", "sqrt", "sq")) ||
       !(xform[2] %in% c("no", "log", "sqrt", "sq"))) {
     stop("Please specify xform appropriately.")
   }
-  if (!is.numeric(shift) | length(shift) != 2) {
+  if (!is.numeric(shift) || length(shift) != 2) {
     stop("The parameter shift must be a numeric vector of length 2.")
   }
 
@@ -1123,9 +1124,11 @@ extract_from_ll_wcsl <- function(ll, element) {
     stop("The parameter ll must be a list of lists returned by ",
          "get_wcs_limit() at level three.")
   }
-  if (sum(vapply(ll, function(x)
+  if (sum(vapply(ll, function(x) {
     sum(c("delta.lim", "delta.lim.orig", "wcs.lim", "wcs.lim.orig") %in%
-                                     names(x[[1]][[1]])) != 4, logical(1)))) {
+        names(x[[1]][[1]])) != 4
+  },
+  logical(1)))) {
     stop("The element was not found in the element names of the list ",
          "at level three that must be a list returned by get_wcs_limit().")
   }
@@ -1202,17 +1205,24 @@ extract_wc_x <- function(l1, l2) {
          "and \"dids\".")
   }
   if (get_n_list_levels(l1) == 1) {
-    if (sum(vapply(l1, function(x) !is.matrix(x), logical(1))) > 0) {
+    if (sum(vapply(l1, function(x) {
+      !is.matrix(x)
+    },
+    logical(1))) > 0) {
       stop("The elements of l1 must be matrices or lists of vectors.")
     }
   } else {
-    if (sum(vapply(l1, function(x)
-      !is.numeric(x[[1]]) & !is.logical(x[[1]]), logical(1))) > 0) {
+    if (sum(vapply(l1, function(x) {
+      !is.numeric(x[[1]]) & !is.logical(x[[1]])
+    },
+    logical(1))) > 0) {
       stop("The elements of l1 must be matrices or lists of vectors.")
     }
   }
-  if (sum(vapply(l2, function(x)
-    !is.numeric(x) & !is.logical(x), logical(1))) > 0) {
+  if (sum(vapply(l2, function(x) {
+    !is.numeric(x) & !is.logical(x)
+  },
+  logical(1))) > 0) {
     stop("The elements of l2 must be numeric vectors or vectors of NA.")
   }
   if (sum(vapply(l1, function(x) is.matrix(x), logical(1))) == 3) {
@@ -1233,8 +1243,11 @@ extract_wc_x <- function(l1, l2) {
       if (is.matrix(l1[["cics"]])) {
         m_res[, "cics"] <- l1[["cics"]]
       }
-      if (is.vector(l1[["cics"]][[1]]) & length(l1[["cics"]][[1]]) == 1) {
-        m_res[, "cics"] <- rep(unname(l1[[i]][[1]]), length(l2[[1]]))
+      if (is.list(l1[["cics"]])) {
+        if (is.vector(l1[["cics"]][[length(l1[["cics"]])]]) &&
+            length(l1[["cics"]][[length(l1[["cics"]])]]) == 1) {
+          m_res[, "cics"] <- rep(unname(l1[[i]][[1]]), length(l2[[1]]))
+        }
       }
     } else {
       if (is.matrix(l1[[i]])) {
@@ -1243,15 +1256,14 @@ extract_wc_x <- function(l1, l2) {
                  l1[[i]][j, l2[[i]][j]],
                  NA)
         }, numeric(1))
-      } else {
-        if (is.list(l1[[i]])) {
-          m_res[, i] <- vapply(seq_along(l2[[1]]), function(j) {
-            ifelse(!is.na(l2[[i]][j]),
-                   l1[[i]][[1]][l2[[i]][j]],
-                   NA)
-          },
-          numeric(1))
-        }
+      }
+      if (is.list(l1[[i]])) {
+        m_res[, i] <- vapply(seq_along(l2[[1]]), function(j) {
+          ifelse(!is.na(l2[[i]][j]),
+                 l1[[i]][[1]][l2[[i]][j]],
+                 NA)
+        },
+        numeric(1))
       }
     }
   }
@@ -1300,13 +1312,13 @@ print_val <- function(val_name, val_value, val_unit, val_sf,
   if (length(val_value) > 1) {
     stop("The parameter val_value must be a numeric value of length 1.")
   }
-  if (!is.numeric(val_value) & !is.na(val_value)) {
+  if (!is.numeric(val_value) && !is.na(val_value)) {
     stop("The parameter val_value must be a numeric value of length 1.")
   }
   if (!is.character(val_unit)) {
     stop("The parameter val_unit must be a string.")
   }
-  if (!is.numeric(val_sf) | length(val_sf) > 1) {
+  if (!is.numeric(val_sf) || length(val_sf) > 1) {
     stop("The parameter val_sf must be a positive integer of length 1.")
   }
   if (val_sf != as.integer(val_sf)) {
@@ -1361,7 +1373,7 @@ print_val <- function(val_name, val_value, val_unit, val_sf,
 #' @keywords internal
 
 get_n_whole_part <- function(x) {
-  if (!is.numeric(x) & all(!is.na(x))) {
+  if (!is.numeric(x) && all(!is.na(x))) {
     stop("The parameter x must be a numeric value or NA.")
   }
 
@@ -1372,7 +1384,7 @@ get_n_whole_part <- function(x) {
     if (is.na(xx)) {
       NA
     } else {
-      if (xx <= 1 & xx >= -1) {
+      if (xx <= 1 && xx >= -1) {
         1
       } else {
         floor(log10(abs(xx))) + 1
